==> nxtvepg-2.8.0.tar.gz: nxtvepg-2.8.0/epgctl/epgversion.h <==
/*
 *  Software version of the Nextview decoder
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation. You find a copy of this
 *  license in the file COPYRIGHT in the root directory of this release.
 *
 *  THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 *  BUT WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
 *  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *
 *  Description:
 *
 *    Defines the software version in various formats.
 *
 *  Author: Tom Zoerner
 *
 *  $Id: epgversion.h,v 1.86 2007/12/31 20:19:55 tom Exp tom $
 */


#ifndef __EPGVERSION_H
#define __EPGVERSION_H


#define NXTVEPG_URL         "http://nxtvepg.sourceforge.net/"
#define NXTVEPG_MAILTO      "tomzo@users.sourceforge.net"

#define EPG_VERSION_MAJOR   2   // major revision
#define EPG_VERSION_MINOR   8   // minor revision
#define EPG_VERSION_PL      0   // bugfix revision / patch level

#define EPG_VERSION_STR     "2.8.0"


// RCS id to be included to the object code for ident(1)
#define EPG_VERSION_RCS_ID  "$Id: epgversion.h,v 1.86 2007/12/31 20:19:55 tom Exp tom $" "$Compiledate: " __DATE__ " " __TIME__" $";

// version in integer format for internal purposes
#define EPG_VERSION_TO_INT(MAJ,MIN,PL) (((MAJ)<<16) | ((MIN)<<8) | (PL))
#define EPG_VERSION_NO      EPG_VERSION_TO_INT(EPG_VERSION_MAJOR, EPG_VERSION_MINOR, EPG_VERSION_PL)


#endif  // __EPGVERSION_H

==> nxtvepg-2.8.1.tar.gz: nxtvepg-2.8.1/epgctl/epgversion.h <==
/*
 *  Software version of the Nextview decoder
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation. You find a copy of this
 *  license in the file COPYRIGHT in the root directory of this release.
 *
 *  THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 *  BUT WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
 *  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *
 *  Description:
 *
 *    Defines the software version in various formats.
 *
 *  Author: Tom Zoerner
 *
 *  $Id: epgversion.h,v 1.91 2008/10/03 22:06:03 tom Exp tom $
 */


#ifndef __EPGVERSION_H
#define __EPGVERSION_H


#define NXTVEPG_URL         "http://nxtvepg.sourceforge.net/"
#define NXTVEPG_MAILTO      "tomzo@users.sourceforge.net"

#define EPG_VERSION_MAJOR   2   // major revision
#define EPG_VERSION_MINOR   8   // minor revision
#define EPG_VERSION_PL   0x84   // bugfix revision / patch level

#define EPG_VERSION_STR     "2.8.1"


// RCS id to be included to the object code for ident(1)
#define EPG_VERSION_RCS_ID  "$Id: epgversion.h,v 1.91 2008/10/03 22:06:03 tom Exp tom $" "$Compiledate: " __DATE__ " " __TIME__" $";

// version in integer format for internal purposes
#define EPG_VERSION_TO_INT(MAJ,MIN,PL) (((MAJ)<<16) | ((MIN)<<8) | (PL))
#define EPG_VERSION_NO      EPG_VERSION_TO_INT(EPG_VERSION_MAJOR, EPG_VERSION_MINOR, EPG_VERSION_PL)


#endif  // __EPGVERSION_H
